@@ -30,11 +30,11 @@ from typing import (
     TypeVar,
 )
 
-from .pure import aflatten as _pure_aflatten
+from astream.pure import aflatten as _pure_aflatten
 
-from .sentinel import _NoValueT, Sentinel
-from .stream import FnTransformer, Stream, stream, transformer, Transformer
-from .utils import create_future, ensure_async_iterator, ensure_coroutine_function
+from astream.sentinel import _NoValueT, Sentinel
+from astream.stream import FnTransformer, Stream, stream, transformer, Transformer
+from astream.utils import create_future, ensure_async_iterator, ensure_coroutine_function
 
 _T = TypeVar("_T")
 _U = TypeVar("_U")
@@ -619,6 +619,25 @@ async def take(async_iterator: AsyncIterator[_T], n: int) -> AsyncIterator[_T]:
         yield await anext(async_iterator)
 
 
+@transformer
+async def take_while(
+    async_iterator: AsyncIterator[_T],
+    predicate: Callable[[_T], Coroutine[Any, Any, bool]] | Callable[[_T], bool],
+) -> AsyncIterator[_T]:
+    """Take the first `n` items from the stream.
+
+    Examples: # todo
+    """
+    _predicate = cast(
+        Callable[[_T], Coroutine[Any, Any, bool]], ensure_coroutine_function(predicate)
+    )
+    async for item in async_iterator:
+        if await _predicate(item):
+            yield item
+        else:
+            break
+
+
 @transformer
 async def drop(async_iterator: AsyncIterator[_T], n: int) -> AsyncIterator[_T]:
     """Drop the first `n` items from the stream.
@@ -636,6 +655,21 @@ async def drop(async_iterator: AsyncIterator[_T], n: int) -> AsyncIterator[_T]:
         yield item
 
 
+@transformer
+async def drop_while(
+    async_iterator: AsyncIterator[_T],
+    predicate: Callable[[_T], Coroutine[Any, Any, bool]] | Callable[[_T], bool],
+) -> AsyncIterator[_T]:
+    _predicate = cast(
+        Callable[[_T], Coroutine[Any, Any, bool]], ensure_coroutine_function(predicate)
+    )
+    async for item in async_iterator:
+        if not await _predicate(item):
+            break
+    async for item in async_iterator:
+        yield item
+
+
 @transformer
 async def immediately_unique(
     async_iterator: AsyncIterator[_T], key: Callable[[_T], Any] = lambda x: x
@@ -709,8 +743,11 @@ async def unique(
             seen.add(new_key)
 
 
+_AsyncIteratorT = TypeVar("_AsyncIteratorT", bound=AsyncIterator[Any])
+
+
 @transformer
-async def delay(async_iterator: AsyncIterator[_T], delay: float) -> AsyncIterator[_T]:
+async def delay(async_iterator: AsyncIterator[_U], delay: float) -> AsyncIterator[_U]:
     """Delay each item in the stream by `delay` seconds.
 
     Args:
@@ -718,7 +755,7 @@ async def delay(async_iterator: AsyncIterator[_T], delay: float) -> AsyncIterato
 
     Examples:
         >>> async def demo_delay() -> None:
-        ...     async for item in range(3) / delay(0.5):
+        ...     async for item in arange(3) / delay(0.5):
         ...         print(item)
         >>> asyncio.run(demo_delay())
         0
